sleb128

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 25, 2025 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package sleb128 reads and writes signed LEB128 integers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Read

func Read(r io.ByteReader) (v int64, n int, err error)

Read reads a signed LEB128 value from r. Returns the value, number of bytes read, and/or an error.

func Write

func Write(w io.ByteWriter, v int64) (n int, err error)

Write writes v in signed LEB128 format to w. Returns the number of bytes written and/or an error.

Adapted from the Go standard library with the following copyright: Copyright 2018 The Go Authors. All rights reserved. Use of this source code is governed by a BSD-style license that can be found in the LICENSE file.

Types

This section is empty.

Jump to